summaryrefslogtreecommitdiffstats
path: root/test
diff options
context:
space:
mode:
Diffstat (limited to 'test')
-rw-r--r--test/.distdep358
-rw-r--r--test/big.c10
-rw-r--r--test/cmpd_dset.c2
-rw-r--r--test/dsets.c4
-rw-r--r--test/h5test.c80
-rw-r--r--test/istore.c15
-rw-r--r--test/ohdr.c12
-rw-r--r--test/overhead.c4
-rw-r--r--test/stab.c3
-rw-r--r--test/tfile.c27
-rw-r--r--test/tselect.c2
-rw-r--r--test/tvltypes.c8
12 files changed, 259 insertions, 266 deletions
diff --git a/test/.distdep b/test/.distdep
index 47dc29d..cd429b7 100644
--- a/test/.distdep
+++ b/test/.distdep
@@ -12,10 +12,10 @@ h5test.lo: \
../src/H5Dpublic.h \
../src/H5Epublic.h \
../src/H5Fpublic.h \
+ ../src/H5FDpublic.h \
../src/H5Gpublic.h \
../src/H5HGpublic.h \
../src/H5HLpublic.h \
- ../src/H5MFpublic.h \
../src/H5MMpublic.h \
../src/H5Opublic.h \
../src/H5Ppublic.h \
@@ -24,6 +24,10 @@ h5test.lo: \
../src/H5RApublic.h \
../src/H5Spublic.h \
../src/H5Tpublic.h \
+ ../src/H5FDcore.h \
+ ../src/H5FDfamily.h \
+ ../src/H5FDmpio.h \
+ ../src/H5FDsec2.h \
../src/H5private.h \
../src/H5Tpkg.h \
../src/H5HGprivate.h \
@@ -44,10 +48,10 @@ big.lo: \
../src/H5Dpublic.h \
../src/H5Epublic.h \
../src/H5Fpublic.h \
+ ../src/H5FDpublic.h \
../src/H5Gpublic.h \
../src/H5HGpublic.h \
../src/H5HLpublic.h \
- ../src/H5MFpublic.h \
../src/H5MMpublic.h \
../src/H5Opublic.h \
../src/H5Ppublic.h \
@@ -56,6 +60,10 @@ big.lo: \
../src/H5RApublic.h \
../src/H5Spublic.h \
../src/H5Tpublic.h \
+ ../src/H5FDcore.h \
+ ../src/H5FDfamily.h \
+ ../src/H5FDmpio.h \
+ ../src/H5FDsec2.h \
../src/H5private.h \
../src/H5Tpkg.h \
../src/H5HGprivate.h \
@@ -76,10 +84,10 @@ bittests.lo: \
../src/H5Dpublic.h \
../src/H5Epublic.h \
../src/H5Fpublic.h \
+ ../src/H5FDpublic.h \
../src/H5Gpublic.h \
../src/H5HGpublic.h \
../src/H5HLpublic.h \
- ../src/H5MFpublic.h \
../src/H5MMpublic.h \
../src/H5Opublic.h \
../src/H5Ppublic.h \
@@ -88,6 +96,10 @@ bittests.lo: \
../src/H5RApublic.h \
../src/H5Spublic.h \
../src/H5Tpublic.h \
+ ../src/H5FDcore.h \
+ ../src/H5FDfamily.h \
+ ../src/H5FDmpio.h \
+ ../src/H5FDsec2.h \
../src/H5private.h \
../src/H5Tpkg.h \
../src/H5HGprivate.h \
@@ -107,10 +119,10 @@ chunk.lo: \
../src/H5Dpublic.h \
../src/H5Epublic.h \
../src/H5Fpublic.h \
+ ../src/H5FDpublic.h \
../src/H5Gpublic.h \
../src/H5HGpublic.h \
../src/H5HLpublic.h \
- ../src/H5MFpublic.h \
../src/H5MMpublic.h \
../src/H5Opublic.h \
../src/H5Ppublic.h \
@@ -118,7 +130,11 @@ chunk.lo: \
../src/H5Rpublic.h \
../src/H5RApublic.h \
../src/H5Spublic.h \
- ../src/H5Tpublic.h
+ ../src/H5Tpublic.h \
+ ../src/H5FDcore.h \
+ ../src/H5FDfamily.h \
+ ../src/H5FDmpio.h \
+ ../src/H5FDsec2.h
cmpd_dset.lo: \
cmpd_dset.c \
h5test.h \
@@ -133,10 +149,10 @@ cmpd_dset.lo: \
../src/H5Dpublic.h \
../src/H5Epublic.h \
../src/H5Fpublic.h \
+ ../src/H5FDpublic.h \
../src/H5Gpublic.h \
../src/H5HGpublic.h \
../src/H5HLpublic.h \
- ../src/H5MFpublic.h \
../src/H5MMpublic.h \
../src/H5Opublic.h \
../src/H5Ppublic.h \
@@ -145,6 +161,10 @@ cmpd_dset.lo: \
../src/H5RApublic.h \
../src/H5Spublic.h \
../src/H5Tpublic.h \
+ ../src/H5FDcore.h \
+ ../src/H5FDfamily.h \
+ ../src/H5FDmpio.h \
+ ../src/H5FDsec2.h \
../src/H5private.h \
../src/H5Tpkg.h \
../src/H5HGprivate.h \
@@ -165,10 +185,10 @@ dsets.lo: \
../src/H5Dpublic.h \
../src/H5Epublic.h \
../src/H5Fpublic.h \
+ ../src/H5FDpublic.h \
../src/H5Gpublic.h \
../src/H5HGpublic.h \
../src/H5HLpublic.h \
- ../src/H5MFpublic.h \
../src/H5MMpublic.h \
../src/H5Opublic.h \
../src/H5Ppublic.h \
@@ -177,6 +197,10 @@ dsets.lo: \
../src/H5RApublic.h \
../src/H5Spublic.h \
../src/H5Tpublic.h \
+ ../src/H5FDcore.h \
+ ../src/H5FDfamily.h \
+ ../src/H5FDmpio.h \
+ ../src/H5FDsec2.h \
../src/H5private.h \
../src/H5Tpkg.h \
../src/H5HGprivate.h \
@@ -197,10 +221,10 @@ dtypes.lo: \
../src/H5Dpublic.h \
../src/H5Epublic.h \
../src/H5Fpublic.h \
+ ../src/H5FDpublic.h \
../src/H5Gpublic.h \
../src/H5HGpublic.h \
../src/H5HLpublic.h \
- ../src/H5MFpublic.h \
../src/H5MMpublic.h \
../src/H5Opublic.h \
../src/H5Ppublic.h \
@@ -209,6 +233,10 @@ dtypes.lo: \
../src/H5RApublic.h \
../src/H5Spublic.h \
../src/H5Tpublic.h \
+ ../src/H5FDcore.h \
+ ../src/H5FDfamily.h \
+ ../src/H5FDmpio.h \
+ ../src/H5FDsec2.h \
../src/H5private.h \
../src/H5Tpkg.h \
../src/H5HGprivate.h \
@@ -229,10 +257,10 @@ extend.lo: \
../src/H5Dpublic.h \
../src/H5Epublic.h \
../src/H5Fpublic.h \
+ ../src/H5FDpublic.h \
../src/H5Gpublic.h \
../src/H5HGpublic.h \
../src/H5HLpublic.h \
- ../src/H5MFpublic.h \
../src/H5MMpublic.h \
../src/H5Opublic.h \
../src/H5Ppublic.h \
@@ -241,6 +269,10 @@ extend.lo: \
../src/H5RApublic.h \
../src/H5Spublic.h \
../src/H5Tpublic.h \
+ ../src/H5FDcore.h \
+ ../src/H5FDfamily.h \
+ ../src/H5FDmpio.h \
+ ../src/H5FDsec2.h \
../src/H5private.h \
../src/H5Tpkg.h \
../src/H5HGprivate.h \
@@ -261,10 +293,10 @@ external.lo: \
../src/H5Dpublic.h \
../src/H5Epublic.h \
../src/H5Fpublic.h \
+ ../src/H5FDpublic.h \
../src/H5Gpublic.h \
../src/H5HGpublic.h \
../src/H5HLpublic.h \
- ../src/H5MFpublic.h \
../src/H5MMpublic.h \
../src/H5Opublic.h \
../src/H5Ppublic.h \
@@ -273,6 +305,10 @@ external.lo: \
../src/H5RApublic.h \
../src/H5Spublic.h \
../src/H5Tpublic.h \
+ ../src/H5FDcore.h \
+ ../src/H5FDfamily.h \
+ ../src/H5FDmpio.h \
+ ../src/H5FDsec2.h \
../src/H5private.h \
../src/H5Tpkg.h \
../src/H5HGprivate.h \
@@ -293,10 +329,10 @@ fillval.lo: \
../src/H5Dpublic.h \
../src/H5Epublic.h \
../src/H5Fpublic.h \
+ ../src/H5FDpublic.h \
../src/H5Gpublic.h \
../src/H5HGpublic.h \
../src/H5HLpublic.h \
- ../src/H5MFpublic.h \
../src/H5MMpublic.h \
../src/H5Opublic.h \
../src/H5Ppublic.h \
@@ -305,6 +341,10 @@ fillval.lo: \
../src/H5RApublic.h \
../src/H5Spublic.h \
../src/H5Tpublic.h \
+ ../src/H5FDcore.h \
+ ../src/H5FDfamily.h \
+ ../src/H5FDmpio.h \
+ ../src/H5FDsec2.h \
../src/H5private.h \
../src/H5Tpkg.h \
../src/H5HGprivate.h \
@@ -325,10 +365,10 @@ flush1.lo: \
../src/H5Dpublic.h \
../src/H5Epublic.h \
../src/H5Fpublic.h \
+ ../src/H5FDpublic.h \
../src/H5Gpublic.h \
../src/H5HGpublic.h \
../src/H5HLpublic.h \
- ../src/H5MFpublic.h \
../src/H5MMpublic.h \
../src/H5Opublic.h \
../src/H5Ppublic.h \
@@ -337,6 +377,10 @@ flush1.lo: \
../src/H5RApublic.h \
../src/H5Spublic.h \
../src/H5Tpublic.h \
+ ../src/H5FDcore.h \
+ ../src/H5FDfamily.h \
+ ../src/H5FDmpio.h \
+ ../src/H5FDsec2.h \
../src/H5private.h \
../src/H5Tpkg.h \
../src/H5HGprivate.h \
@@ -357,10 +401,10 @@ flush2.lo: \
../src/H5Dpublic.h \
../src/H5Epublic.h \
../src/H5Fpublic.h \
+ ../src/H5FDpublic.h \
../src/H5Gpublic.h \
../src/H5HGpublic.h \
../src/H5HLpublic.h \
- ../src/H5MFpublic.h \
../src/H5MMpublic.h \
../src/H5Opublic.h \
../src/H5Ppublic.h \
@@ -369,6 +413,10 @@ flush2.lo: \
../src/H5RApublic.h \
../src/H5Spublic.h \
../src/H5Tpublic.h \
+ ../src/H5FDcore.h \
+ ../src/H5FDfamily.h \
+ ../src/H5FDmpio.h \
+ ../src/H5FDsec2.h \
../src/H5private.h \
../src/H5Tpkg.h \
../src/H5HGprivate.h \
@@ -389,10 +437,10 @@ gheap.lo: \
../src/H5Dpublic.h \
../src/H5Epublic.h \
../src/H5Fpublic.h \
+ ../src/H5FDpublic.h \
../src/H5Gpublic.h \
../src/H5HGpublic.h \
../src/H5HLpublic.h \
- ../src/H5MFpublic.h \
../src/H5MMpublic.h \
../src/H5Opublic.h \
../src/H5Ppublic.h \
@@ -401,6 +449,10 @@ gheap.lo: \
../src/H5RApublic.h \
../src/H5Spublic.h \
../src/H5Tpublic.h \
+ ../src/H5FDcore.h \
+ ../src/H5FDfamily.h \
+ ../src/H5FDmpio.h \
+ ../src/H5FDsec2.h \
../src/H5private.h \
../src/H5Tpkg.h \
../src/H5HGprivate.h \
@@ -431,10 +483,10 @@ iopipe.lo: \
../src/H5Dpublic.h \
../src/H5Epublic.h \
../src/H5Fpublic.h \
+ ../src/H5FDpublic.h \
../src/H5Gpublic.h \
../src/H5HGpublic.h \
../src/H5HLpublic.h \
- ../src/H5MFpublic.h \
../src/H5MMpublic.h \
../src/H5Opublic.h \
../src/H5Ppublic.h \
@@ -442,7 +494,11 @@ iopipe.lo: \
../src/H5Rpublic.h \
../src/H5RApublic.h \
../src/H5Spublic.h \
- ../src/H5Tpublic.h
+ ../src/H5Tpublic.h \
+ ../src/H5FDcore.h \
+ ../src/H5FDfamily.h \
+ ../src/H5FDmpio.h \
+ ../src/H5FDsec2.h
istore.lo: \
istore.c \
h5test.h \
@@ -457,10 +513,10 @@ istore.lo: \
../src/H5Dpublic.h \
../src/H5Epublic.h \
../src/H5Fpublic.h \
+ ../src/H5FDpublic.h \
../src/H5Gpublic.h \
../src/H5HGpublic.h \
../src/H5HLpublic.h \
- ../src/H5MFpublic.h \
../src/H5MMpublic.h \
../src/H5Opublic.h \
../src/H5Ppublic.h \
@@ -469,6 +525,10 @@ istore.lo: \
../src/H5RApublic.h \
../src/H5Spublic.h \
../src/H5Tpublic.h \
+ ../src/H5FDcore.h \
+ ../src/H5FDfamily.h \
+ ../src/H5FDmpio.h \
+ ../src/H5FDsec2.h \
../src/H5private.h \
../src/H5Tpkg.h \
../src/H5HGprivate.h \
@@ -498,10 +558,10 @@ lheap.lo: \
../src/H5Dpublic.h \
../src/H5Epublic.h \
../src/H5Fpublic.h \
+ ../src/H5FDpublic.h \
../src/H5Gpublic.h \
../src/H5HGpublic.h \
../src/H5HLpublic.h \
- ../src/H5MFpublic.h \
../src/H5MMpublic.h \
../src/H5Opublic.h \
../src/H5Ppublic.h \
@@ -510,6 +570,10 @@ lheap.lo: \
../src/H5RApublic.h \
../src/H5Spublic.h \
../src/H5Tpublic.h \
+ ../src/H5FDcore.h \
+ ../src/H5FDfamily.h \
+ ../src/H5FDmpio.h \
+ ../src/H5FDsec2.h \
../src/H5private.h \
../src/H5Tpkg.h \
../src/H5HGprivate.h \
@@ -533,10 +597,10 @@ links.lo: \
../src/H5Dpublic.h \
../src/H5Epublic.h \
../src/H5Fpublic.h \
+ ../src/H5FDpublic.h \
../src/H5Gpublic.h \
../src/H5HGpublic.h \
../src/H5HLpublic.h \
- ../src/H5MFpublic.h \
../src/H5MMpublic.h \
../src/H5Opublic.h \
../src/H5Ppublic.h \
@@ -545,6 +609,10 @@ links.lo: \
../src/H5RApublic.h \
../src/H5Spublic.h \
../src/H5Tpublic.h \
+ ../src/H5FDcore.h \
+ ../src/H5FDfamily.h \
+ ../src/H5FDmpio.h \
+ ../src/H5FDsec2.h \
../src/H5private.h \
../src/H5Tpkg.h \
../src/H5HGprivate.h \
@@ -565,10 +633,10 @@ mount.lo: \
../src/H5Dpublic.h \
../src/H5Epublic.h \
../src/H5Fpublic.h \
+ ../src/H5FDpublic.h \
../src/H5Gpublic.h \
../src/H5HGpublic.h \
../src/H5HLpublic.h \
- ../src/H5MFpublic.h \
../src/H5MMpublic.h \
../src/H5Opublic.h \
../src/H5Ppublic.h \
@@ -577,6 +645,10 @@ mount.lo: \
../src/H5RApublic.h \
../src/H5Spublic.h \
../src/H5Tpublic.h \
+ ../src/H5FDcore.h \
+ ../src/H5FDfamily.h \
+ ../src/H5FDmpio.h \
+ ../src/H5FDsec2.h \
../src/H5private.h \
../src/H5Tpkg.h \
../src/H5HGprivate.h \
@@ -597,10 +669,10 @@ mtime.lo: \
../src/H5Dpublic.h \
../src/H5Epublic.h \
../src/H5Fpublic.h \
+ ../src/H5FDpublic.h \
../src/H5Gpublic.h \
../src/H5HGpublic.h \
../src/H5HLpublic.h \
- ../src/H5MFpublic.h \
../src/H5MMpublic.h \
../src/H5Opublic.h \
../src/H5Ppublic.h \
@@ -609,6 +681,10 @@ mtime.lo: \
../src/H5RApublic.h \
../src/H5Spublic.h \
../src/H5Tpublic.h \
+ ../src/H5FDcore.h \
+ ../src/H5FDfamily.h \
+ ../src/H5FDmpio.h \
+ ../src/H5FDsec2.h \
../src/H5private.h \
../src/H5Tpkg.h \
../src/H5HGprivate.h \
@@ -629,10 +705,10 @@ ohdr.lo: \
../src/H5Dpublic.h \
../src/H5Epublic.h \
../src/H5Fpublic.h \
+ ../src/H5FDpublic.h \
../src/H5Gpublic.h \
../src/H5HGpublic.h \
../src/H5HLpublic.h \
- ../src/H5MFpublic.h \
../src/H5MMpublic.h \
../src/H5Opublic.h \
../src/H5Ppublic.h \
@@ -641,6 +717,10 @@ ohdr.lo: \
../src/H5RApublic.h \
../src/H5Spublic.h \
../src/H5Tpublic.h \
+ ../src/H5FDcore.h \
+ ../src/H5FDfamily.h \
+ ../src/H5FDmpio.h \
+ ../src/H5FDsec2.h \
../src/H5private.h \
../src/H5Tpkg.h \
../src/H5HGprivate.h \
@@ -666,10 +746,10 @@ overhead.lo: \
../src/H5Dpublic.h \
../src/H5Epublic.h \
../src/H5Fpublic.h \
+ ../src/H5FDpublic.h \
../src/H5Gpublic.h \
../src/H5HGpublic.h \
../src/H5HLpublic.h \
- ../src/H5MFpublic.h \
../src/H5MMpublic.h \
../src/H5Opublic.h \
../src/H5Ppublic.h \
@@ -677,7 +757,11 @@ overhead.lo: \
../src/H5Rpublic.h \
../src/H5RApublic.h \
../src/H5Spublic.h \
- ../src/H5Tpublic.h
+ ../src/H5Tpublic.h \
+ ../src/H5FDcore.h \
+ ../src/H5FDfamily.h \
+ ../src/H5FDmpio.h \
+ ../src/H5FDsec2.h
ragged.lo: \
ragged.c \
../src/hdf5.h \
@@ -691,10 +775,10 @@ ragged.lo: \
../src/H5Dpublic.h \
../src/H5Epublic.h \
../src/H5Fpublic.h \
+ ../src/H5FDpublic.h \
../src/H5Gpublic.h \
../src/H5HGpublic.h \
../src/H5HLpublic.h \
- ../src/H5MFpublic.h \
../src/H5MMpublic.h \
../src/H5Opublic.h \
../src/H5Ppublic.h \
@@ -703,6 +787,10 @@ ragged.lo: \
../src/H5RApublic.h \
../src/H5Spublic.h \
../src/H5Tpublic.h \
+ ../src/H5FDcore.h \
+ ../src/H5FDfamily.h \
+ ../src/H5FDmpio.h \
+ ../src/H5FDsec2.h \
../src/H5private.h
stab.lo: \
stab.c \
@@ -718,10 +806,10 @@ stab.lo: \
../src/H5Dpublic.h \
../src/H5Epublic.h \
../src/H5Fpublic.h \
+ ../src/H5FDpublic.h \
../src/H5Gpublic.h \
../src/H5HGpublic.h \
../src/H5HLpublic.h \
- ../src/H5MFpublic.h \
../src/H5MMpublic.h \
../src/H5Opublic.h \
../src/H5Ppublic.h \
@@ -730,6 +818,10 @@ stab.lo: \
../src/H5RApublic.h \
../src/H5Spublic.h \
../src/H5Tpublic.h \
+ ../src/H5FDcore.h \
+ ../src/H5FDfamily.h \
+ ../src/H5FDmpio.h \
+ ../src/H5FDsec2.h \
../src/H5private.h \
../src/H5Tpkg.h \
../src/H5HGprivate.h \
@@ -755,17 +847,20 @@ tattr.lo: \
../src/H5Bpublic.h \
../src/H5Dpublic.h \
../src/H5Fpublic.h \
+ ../src/H5FDpublic.h \
../src/H5Gpublic.h \
../src/H5HGpublic.h \
../src/H5HLpublic.h \
- ../src/H5MFpublic.h \
../src/H5MMpublic.h \
../src/H5Opublic.h \
../src/H5Ppublic.h \
../src/H5Zpublic.h \
../src/H5Rpublic.h \
../src/H5RApublic.h \
- ../src/H5Spublic.h
+ ../src/H5Spublic.h \
+ ../src/H5Tpublic.h \
+ ../src/H5FDcore.h \
+ ../src/H5FDfamily.h
testhdf5.lo: \
testhdf5.c \
testhdf5.h \
@@ -789,7 +884,10 @@ tfile.lo: \
../src/H5Bpublic.h \
../src/H5Fprivate.h \
../src/H5Fpublic.h \
- ../src/H5Dpublic.h
+ ../src/H5FDpublic.h \
+ ../src/H5MMpublic.h \
+ ../src/H5Pprivate.h \
+ ../src/H5Ppublic.h
th5s.lo: \
th5s.c \
testhdf5.h \
@@ -804,9 +902,11 @@ th5s.lo: \
../src/H5Bpublic.h \
../src/H5Fprivate.h \
../src/H5Fpublic.h \
- ../src/H5Dpublic.h \
+ ../src/H5FDpublic.h \
+ ../src/H5MMpublic.h \
../src/H5Sprivate.h \
../src/H5Spublic.h \
+ ../src/H5Dpublic.h \
../src/H5Gprivate.h \
../src/H5Gpublic.h \
../src/H5Oprivate.h \
@@ -815,8 +915,9 @@ th5s.lo: \
../src/H5HGpublic.h \
../src/H5Tprivate.h \
../src/H5Tpublic.h \
- ../src/H5Zprivate.h \
- ../src/H5Zpublic.h
+ ../src/H5Rprivate.h \
+ ../src/H5Rpublic.h \
+ ../src/H5Zprivate.h
tmeta.lo: \
tmeta.c \
testhdf5.h \
@@ -845,17 +946,20 @@ trefer.lo: \
../src/H5Bpublic.h \
../src/H5Dpublic.h \
../src/H5Fpublic.h \
+ ../src/H5FDpublic.h \
../src/H5Gpublic.h \
../src/H5HGpublic.h \
../src/H5HLpublic.h \
- ../src/H5MFpublic.h \
../src/H5MMpublic.h \
../src/H5Opublic.h \
../src/H5Ppublic.h \
../src/H5Zpublic.h \
../src/H5Rpublic.h \
../src/H5RApublic.h \
- ../src/H5Spublic.h
+ ../src/H5Spublic.h \
+ ../src/H5Tpublic.h \
+ ../src/H5FDcore.h \
+ ../src/H5FDfamily.h
tselect.lo: \
tselect.c \
testhdf5.h \
@@ -872,17 +976,20 @@ tselect.lo: \
../src/H5Bpublic.h \
../src/H5Dpublic.h \
../src/H5Fpublic.h \
+ ../src/H5FDpublic.h \
../src/H5Gpublic.h \
../src/H5HGpublic.h \
../src/H5HLpublic.h \
- ../src/H5MFpublic.h \
../src/H5MMpublic.h \
../src/H5Opublic.h \
../src/H5Ppublic.h \
../src/H5Zpublic.h \
../src/H5Rpublic.h \
../src/H5RApublic.h \
- ../src/H5Spublic.h
+ ../src/H5Spublic.h \
+ ../src/H5Tpublic.h \
+ ../src/H5FDcore.h \
+ ../src/H5FDfamily.h
tvltypes.lo: \
tvltypes.c \
testhdf5.h \
@@ -899,17 +1006,20 @@ tvltypes.lo: \
../src/H5Bpublic.h \
../src/H5Dpublic.h \
../src/H5Fpublic.h \
+ ../src/H5FDpublic.h \
../src/H5Gpublic.h \
../src/H5HGpublic.h \
../src/H5HLpublic.h \
- ../src/H5MFpublic.h \
../src/H5MMpublic.h \
../src/H5Opublic.h \
../src/H5Ppublic.h \
../src/H5Zpublic.h \
../src/H5Rpublic.h \
../src/H5RApublic.h \
- ../src/H5Spublic.h
+ ../src/H5Spublic.h \
+ ../src/H5Tpublic.h \
+ ../src/H5FDcore.h \
+ ../src/H5FDfamily.h
unlink.lo: \
unlink.c \
h5test.h \
@@ -924,10 +1034,10 @@ unlink.lo: \
../src/H5Dpublic.h \
../src/H5Epublic.h \
../src/H5Fpublic.h \
+ ../src/H5FDpublic.h \
../src/H5Gpublic.h \
../src/H5HGpublic.h \
../src/H5HLpublic.h \
- ../src/H5MFpublic.h \
../src/H5MMpublic.h \
../src/H5Opublic.h \
../src/H5Ppublic.h \
@@ -936,6 +1046,10 @@ unlink.lo: \
../src/H5RApublic.h \
../src/H5Spublic.h \
../src/H5Tpublic.h \
+ ../src/H5FDcore.h \
+ ../src/H5FDfamily.h \
+ ../src/H5FDmpio.h \
+ ../src/H5FDsec2.h \
../src/H5private.h \
../src/H5Tpkg.h \
../src/H5HGprivate.h \
@@ -956,170 +1070,10 @@ enum.lo: \
../src/H5Dpublic.h \
../src/H5Epublic.h \
../src/H5Fpublic.h \
+ ../src/H5FDpublic.h \
../src/H5Gpublic.h \
../src/H5HGpublic.h \
../src/H5HLpublic.h \
- ../src/H5MFpublic.h \
- ../src/H5MMpublic.h \
- ../src/H5Opublic.h \
- ../src/H5Ppublic.h \
- ../src/H5Zpublic.h \
- ../src/H5Rpublic.h \
- ../src/H5RApublic.h \
- ../src/H5Spublic.h \
- ../src/H5Tpublic.h \
- ../src/H5private.h \
- ../src/H5Tpkg.h \
- ../src/H5HGprivate.h \
- ../src/H5Fprivate.h \
- ../src/H5Rprivate.h \
- ../src/H5Tprivate.h
-h5test.lo: \
- h5test.c \
- h5test.h \
- ../src/hdf5.h \
- ../src/H5public.h \
- ../src/H5config.h \
- ../src/H5api_adpt.h \
- ../src/H5Ipublic.h \
- ../src/H5Apublic.h \
- ../src/H5ACpublic.h \
- ../src/H5Bpublic.h \
- ../src/H5Dpublic.h \
- ../src/H5Epublic.h \
- ../src/H5Fpublic.h \
- ../src/H5Gpublic.h \
- ../src/H5HGpublic.h \
- ../src/H5HLpublic.h \
- ../src/H5MFpublic.h \
- ../src/H5MMpublic.h \
- ../src/H5Opublic.h \
- ../src/H5Ppublic.h \
- ../src/H5Zpublic.h \
- ../src/H5Rpublic.h \
- ../src/H5RApublic.h \
- ../src/H5Spublic.h \
- ../src/H5Tpublic.h \
- ../src/H5private.h \
- ../src/H5Tpkg.h \
- ../src/H5HGprivate.h \
- ../src/H5Fprivate.h \
- ../src/H5Rprivate.h \
- ../src/H5Tprivate.h
-fillval.lo: \
- fillval.c \
- h5test.h \
- ../src/hdf5.h \
- ../src/H5public.h \
- ../src/H5config.h \
- ../src/H5api_adpt.h \
- ../src/H5Ipublic.h \
- ../src/H5Apublic.h \
- ../src/H5ACpublic.h \
- ../src/H5Bpublic.h \
- ../src/H5Dpublic.h \
- ../src/H5Epublic.h \
- ../src/H5Fpublic.h \
- ../src/H5Gpublic.h \
- ../src/H5HGpublic.h \
- ../src/H5HLpublic.h \
- ../src/H5MFpublic.h \
- ../src/H5MMpublic.h \
- ../src/H5Opublic.h \
- ../src/H5Ppublic.h \
- ../src/H5Zpublic.h \
- ../src/H5Rpublic.h \
- ../src/H5RApublic.h \
- ../src/H5Spublic.h \
- ../src/H5Tpublic.h \
- ../src/H5private.h \
- ../src/H5Tpkg.h \
- ../src/H5HGprivate.h \
- ../src/H5Fprivate.h \
- ../src/H5Rprivate.h \
- ../src/H5Tprivate.h
-dtypes.lo: \
- dtypes.c \
- h5test.h \
- ../src/hdf5.h \
- ../src/H5public.h \
- ../src/H5config.h \
- ../src/H5api_adpt.h \
- ../src/H5Ipublic.h \
- ../src/H5Apublic.h \
- ../src/H5ACpublic.h \
- ../src/H5Bpublic.h \
- ../src/H5Dpublic.h \
- ../src/H5Epublic.h \
- ../src/H5Fpublic.h \
- ../src/H5Gpublic.h \
- ../src/H5HGpublic.h \
- ../src/H5HLpublic.h \
- ../src/H5MFpublic.h \
- ../src/H5MMpublic.h \
- ../src/H5Opublic.h \
- ../src/H5Ppublic.h \
- ../src/H5Zpublic.h \
- ../src/H5Rpublic.h \
- ../src/H5RApublic.h \
- ../src/H5Spublic.h \
- ../src/H5Tpublic.h \
- ../src/H5private.h \
- ../src/H5Tpkg.h \
- ../src/H5HGprivate.h \
- ../src/H5Fprivate.h \
- ../src/H5Rprivate.h \
- ../src/H5Tprivate.h
-flush1.lo: \
- flush1.c \
- h5test.h \
- ../src/hdf5.h \
- ../src/H5public.h \
- ../src/H5config.h \
- ../src/H5api_adpt.h \
- ../src/H5Ipublic.h \
- ../src/H5Apublic.h \
- ../src/H5ACpublic.h \
- ../src/H5Bpublic.h \
- ../src/H5Dpublic.h \
- ../src/H5Epublic.h \
- ../src/H5Fpublic.h \
- ../src/H5Gpublic.h \
- ../src/H5HGpublic.h \
- ../src/H5HLpublic.h \
- ../src/H5MFpublic.h \
- ../src/H5MMpublic.h \
- ../src/H5Opublic.h \
- ../src/H5Ppublic.h \
- ../src/H5Zpublic.h \
- ../src/H5Rpublic.h \
- ../src/H5RApublic.h \
- ../src/H5Spublic.h \
- ../src/H5Tpublic.h \
- ../src/H5private.h \
- ../src/H5Tpkg.h \
- ../src/H5HGprivate.h \
- ../src/H5Fprivate.h \
- ../src/H5Rprivate.h \
- ../src/H5Tprivate.h
-flush2.lo: \
- flush2.c \
- h5test.h \
- ../src/hdf5.h \
- ../src/H5public.h \
- ../src/H5config.h \
- ../src/H5api_adpt.h \
- ../src/H5Ipublic.h \
- ../src/H5Apublic.h \
- ../src/H5ACpublic.h \
- ../src/H5Bpublic.h \
- ../src/H5Dpublic.h \
- ../src/H5Epublic.h \
- ../src/H5Fpublic.h \
- ../src/H5Gpublic.h \
- ../src/H5HGpublic.h \
- ../src/H5HLpublic.h \
- ../src/H5MFpublic.h \
../src/H5MMpublic.h \
../src/H5Opublic.h \
../src/H5Ppublic.h \
@@ -1128,6 +1082,10 @@ flush2.lo: \
../src/H5RApublic.h \
../src/H5Spublic.h \
../src/H5Tpublic.h \
+ ../src/H5FDcore.h \
+ ../src/H5FDfamily.h \
+ ../src/H5FDmpio.h \
+ ../src/H5FDsec2.h \
../src/H5private.h \
../src/H5Tpkg.h \
../src/H5HGprivate.h \
diff --git a/test/big.c b/test/big.c
index 790cdee..b0c4c08 100644
--- a/test/big.c
+++ b/test/big.c
@@ -120,7 +120,7 @@ enough_room(hid_t fapl)
for (i=0; i<NELMTS(fd); i++) fd[i] = -1;
/* Get file name template */
- assert(H5F_LOW_FAMILY==H5Pget_driver(fapl));
+ assert(H5FD_FAMILY==H5Pget_driver(fapl));
h5_fixname(FILENAME[0], fapl, filename, sizeof filename);
/* Create files */
@@ -367,16 +367,16 @@ main (void)
fapl = h5_fileaccess();
/* The file driver must be the family driver */
- if (H5F_LOW_FAMILY!=H5Pget_driver(fapl)) {
+ if (H5FD_FAMILY!=H5Pget_driver(fapl)) {
printf("Changing file drivers to the family driver, %lu bytes each\n",
(unsigned long)FAMILY_SIZE);
- if (H5Pset_family(fapl, FAMILY_SIZE, H5P_DEFAULT)<0) goto error;
- } else if (H5Pget_family(fapl, &family_size, NULL)<0) {
+ if (H5Pset_fapl_family(fapl, FAMILY_SIZE, H5P_DEFAULT)<0) goto error;
+ } else if (H5Pget_fapl_family(fapl, &family_size, NULL)<0) {
goto error;
} else if (family_size!=FAMILY_SIZE) {
printf("Changing family member size from %lu to %lu\n",
(unsigned long)family_size, (unsigned long)FAMILY_SIZE);
- if (H5Pset_family(fapl, FAMILY_SIZE, H5P_DEFAULT)<0) goto error;
+ if (H5Pset_fapl_family(fapl, FAMILY_SIZE, H5P_DEFAULT)<0) goto error;
}
/*
diff --git a/test/cmpd_dset.c b/test/cmpd_dset.c
index 6777ea9..714c810 100644
--- a/test/cmpd_dset.c
+++ b/test/cmpd_dset.c
@@ -155,7 +155,7 @@ main (int argc, char *argv[])
if ((space = H5Screate_simple (2, dim, NULL))<0) goto error;
/* Create xfer properties to preserve initialized data */
- if ((PRESERVE = H5Pcreate (H5P_DATASET_XFER))<0) goto error;
+ if ((PRESERVE = H5Pcreate (H5P_DATA_XFER))<0) goto error;
if (H5Pset_preserve (PRESERVE, 1)<0) goto error;
/*
diff --git a/test/dsets.c b/test/dsets.c
index 8233360..5fe0b26 100644
--- a/test/dsets.c
+++ b/test/dsets.c
@@ -180,7 +180,7 @@ test_simple_io(hid_t file)
/* Create a small conversion buffer to test strip mining */
tconv_buf = malloc (1000);
- xfer = H5Pcreate (H5P_DATASET_XFER);
+ xfer = H5Pcreate (H5P_DATA_XFER);
assert (xfer>=0);
if (H5Pset_buffer (xfer, 1000, tconv_buf, NULL)<0) goto error;
@@ -366,7 +366,7 @@ test_compression(hid_t file)
* Create a small conversion buffer to test strip mining. We
* might as well test all we can!
*/
- if ((xfer = H5Pcreate (H5P_DATASET_XFER))<0) goto error;
+ if ((xfer = H5Pcreate (H5P_DATA_XFER))<0) goto error;
tconv_buf = malloc (1000);
if (H5Pset_buffer (xfer, 1000, tconv_buf, NULL)<0) goto error;
diff --git a/test/h5test.c b/test/h5test.c
index 09b2f06..88a45a9 100644
--- a/test/h5test.c
+++ b/test/h5test.c
@@ -82,6 +82,7 @@ h5_cleanup(hid_t fapl)
char temp[2048];
int i, j;
int retval=0;
+ hid_t driver;
if (!getenv("HDF5_NOCLEANUP")) {
for (i=0; FILENAME[i]; i++) {
@@ -90,29 +91,31 @@ h5_cleanup(hid_t fapl)
continue;
}
- switch (H5Pget_driver(fapl)) {
- case H5F_LOW_CORE:
- break; /*nothing to remove*/
-
- case H5F_LOW_SPLIT:
- HDsnprintf(temp, sizeof temp, "%s.raw", filename);
- remove(temp);
- HDsnprintf(temp, sizeof temp, "%s.meta", filename);
- remove(temp);
- break;
-
- case H5F_LOW_FAMILY:
+ driver = H5Pget_driver(fapl);
+ if (H5FD_FAMILY==driver) {
for (j=0; /*void*/; j++) {
HDsnprintf(temp, sizeof temp, filename, j);
if (access(temp, F_OK)<0) break;
remove(temp);
}
- break;
-
- default:
+ } else if (H5FD_CORE==driver) {
+ /*void*/
+ } else {
remove(filename);
- break;
}
+
+
+#ifndef ROBB_VFL
+#warning "H5F_LOW_SPLIT not implemented"
+#else
+ switch (H5Pget_driver(fapl)) {
+ case H5F_LOW_SPLIT:
+ HDsnprintf(temp, sizeof temp, "%s.raw", filename);
+ remove(temp);
+ HDsnprintf(temp, sizeof temp, "%s.meta", filename);
+ remove(temp);
+ break;
+#endif
}
retval=1;
}
@@ -181,14 +184,15 @@ h5_reset(void)
* Thursday, November 19, 1998
*
* Modifications:
- *
+ * Robb Matzke, 1999-08-03
+ * Modified to use the virtual file layer.
*-------------------------------------------------------------------------
*/
char *
h5_fixname(const char *base_name, hid_t fapl, char *fullname, size_t size)
{
- const char *prefix=NULL, *suffix=NULL;
- H5F_driver_t driver;
+ const char *prefix=NULL, *suffix=NULL;
+ hid_t driver;
if (!base_name || !fullname || size<1) return NULL;
@@ -211,18 +215,22 @@ h5_fixname(const char *base_name, hid_t fapl, char *fullname, size_t size)
/* Append a suffix */
if ((driver=H5Pget_driver(fapl))<0) return NULL;
- switch (driver) {
- case H5F_LOW_SPLIT:
- case H5F_LOW_CORE:
- suffix = NULL;
- break;
- case H5F_LOW_FAMILY:
+ if (H5FD_FAMILY==driver) {
suffix = "%05d.h5";
- break;
- default:
+ } else if (H5FD_CORE==driver) {
+ suffix = NULL;
+ } else {
suffix = ".h5";
- break;
}
+
+#ifndef RPM_VFL
+#warning "H5FD_SPLIT not implemented"
+#else
+ if (H5FD_SPLIT==driver) {
+ suffix = NULL;
+ }
+#endif
+
if (suffix) {
if (strlen(fullname)+strlen(suffix)>=size) return NULL;
strcat(fullname, suffix);
@@ -257,7 +265,7 @@ h5_fileaccess(void)
const char *name;
char s[1024];
hid_t fapl = -1;
- hsize_t fam_size = 1024*1024;
+ hsize_t fam_size = 100*1024*1024; /*100 MB*/
/* First use the environment variable, then the constant */
val = getenv("HDF5_DRIVER");
@@ -274,23 +282,31 @@ h5_fileaccess(void)
if (!strcmp(name, "sec2")) {
/* Unix read() and write() system calls */
- if (H5Pset_sec2(fapl)<0) return -1;
+ if (H5Pset_fapl_sec2(fapl)<0) return -1;
} else if (!strcmp(name, "stdio")) {
/* C standard I/O library */
+#ifndef RPM_VFL
+#warning "H5FD_STDIO not implemented"
+#else
if (H5Pset_stdio(fapl)<0) return -1;
+#endif
} else if (!strcmp(name, "core")) {
/* In-core temporary file with 1MB increment */
- if (H5Pset_core(fapl, 1024*1024)<0) return -1;
+ if (H5Pset_fapl_core(fapl, 1024*1024)<0) return -1;
} else if (!strcmp(name, "split")) {
/* Split meta data and raw data each using default driver */
+#ifndef RPM_VFL
+#warning "H5FD_SPLIT not implemented"
+#else
if (H5Pset_split(fapl, NULL, H5P_DEFAULT, NULL, H5P_DEFAULT)<0)
return -1;
+#endif
} else if (!strcmp(name, "family")) {
/* Family of files, each 1MB and using the default driver */
if ((val=strtok(NULL, " \t\n\r"))) {
fam_size = strtod(val, NULL) * 1024*1024;
}
- if (H5Pset_family(fapl, fam_size, H5P_DEFAULT)<0) return -1;
+ if (H5Pset_fapl_family(fapl, fam_size, H5P_DEFAULT)<0) return -1;
} else {
/* Unknown driver */
return -1;
diff --git a/test/istore.c b/test/istore.c
index 0ccfe5e..b04e0f3 100644
--- a/test/istore.c
+++ b/test/istore.c
@@ -297,7 +297,7 @@ test_extend(H5F_t *f, const char *prefix,
memset(buf, (signed)(128+ctr), (size_t)nelmts);
/* Write to disk */
- if (H5F_arr_write(f, &H5F_xfer_dflt, &layout, NULL, NULL, NULL, size,
+ if (H5F_arr_write(f, H5P_DEFAULT, &layout, NULL, NULL, NULL, size,
size, zero, offset, buf)<0) {
FAILED();
printf(" Write failed: ctr=%lu\n", (unsigned long)ctr);
@@ -306,7 +306,7 @@ test_extend(H5F_t *f, const char *prefix,
/* Read from disk */
memset(check, 0xff, (size_t)nelmts);
- if (H5F_arr_read(f, &H5F_xfer_dflt, &layout, NULL, NULL, NULL, size,
+ if (H5F_arr_read(f, H5P_DEFAULT, &layout, NULL, NULL, NULL, size,
size, zero, offset, check)<0) {
FAILED();
printf(" Read failed: ctr=%lu\n", (unsigned long)ctr);
@@ -337,7 +337,7 @@ test_extend(H5F_t *f, const char *prefix,
/* Now read the entire array back out and check it */
memset(buf, 0xff, nx * ny * nz);
- if (H5F_arr_read(f, &H5F_xfer_dflt, &layout, NULL, NULL, NULL, whole_size,
+ if (H5F_arr_read(f, H5P_DEFAULT, &layout, NULL, NULL, NULL, whole_size,
whole_size, zero, zero, buf)<0) {
FAILED();
puts(" Read failed for whole array.");
@@ -450,7 +450,7 @@ test_sparse(H5F_t *f, const char *prefix, size_t nblocks,
memset(buf, (signed)(128+ctr), nx * ny * nz);
/* write to disk */
- if (H5F_arr_write(f, &H5F_xfer_dflt, &layout, NULL, NULL, NULL, size,
+ if (H5F_arr_write(f, H5P_DEFAULT, &layout, NULL, NULL, NULL, size,
size, zero, offset, buf)<0) {
FAILED();
printf(" Write failed: ctr=%lu\n", (unsigned long)ctr);
@@ -560,10 +560,13 @@ main(int argc, char *argv[])
* For testing file families, fool the library into thinking it already
* allocated a whole bunch of data.
*/
- if (H5F_LOW_FAMILY==H5Pget_driver(fapl)) {
+ if (H5FD_FAMILY==H5Pget_driver(fapl)) {
haddr_t addr;
addr = 8 * ((uint64_t)1<<30); /*8 GB */
- H5F_low_seteof(f->shared->lf, addr);
+ if (H5FDset_eoa(f->shared->lf, addr)<0) {
+ printf("Cannot create large file family\n");
+ exit(1);
+ }
}
/*
diff --git a/test/ohdr.c b/test/ohdr.c
index 2da033b..6fcffe0 100644
--- a/test/ohdr.c
+++ b/test/ohdr.c
@@ -78,7 +78,7 @@ main(void)
H5Eprint(stdout);
goto error;
}
- if (H5AC_flush(f, NULL, H5F_ADDR_UNDEF, TRUE)<0) {
+ if (H5AC_flush(f, NULL, HADDR_UNDEF, TRUE)<0) {
FAILED();
H5Eprint(stdout);
goto error;
@@ -110,7 +110,7 @@ main(void)
H5Eprint(stdout);
goto error;
}
- if (H5AC_flush(f, NULL, H5F_ADDR_UNDEF, TRUE)<0) {
+ if (H5AC_flush(f, NULL, HADDR_UNDEF, TRUE)<0) {
FAILED();
H5Eprint(stdout);
goto error;
@@ -143,7 +143,7 @@ main(void)
H5Eprint(stdout);
goto error;
}
- if (H5AC_flush(f, NULL, H5F_ADDR_UNDEF, TRUE)<0) {
+ if (H5AC_flush(f, NULL, HADDR_UNDEF, TRUE)<0) {
FAILED();
H5Eprint(stdout);
goto error;
@@ -175,7 +175,7 @@ main(void)
H5Eprint(stdout);
goto error;
}
- if (H5AC_flush(f, NULL, H5F_ADDR_UNDEF, TRUE)<0) {
+ if (H5AC_flush(f, NULL, HADDR_UNDEF, TRUE)<0) {
FAILED();
H5Eprint(stdout);
goto error;
@@ -210,7 +210,7 @@ main(void)
goto error;
}
}
- if (H5AC_flush(f, NULL, H5F_ADDR_UNDEF, TRUE)<0) {
+ if (H5AC_flush(f, NULL, HADDR_UNDEF, TRUE)<0) {
FAILED();
H5Eprint(stdout);
goto error;
@@ -230,7 +230,7 @@ main(void)
H5Eprint(stdout);
goto error;
}
- if (H5AC_flush(f, NULL, H5F_ADDR_UNDEF, TRUE)<0) {
+ if (H5AC_flush(f, NULL, HADDR_UNDEF, TRUE)<0) {
FAILED();
H5Eprint(stdout);
goto error;
diff --git a/test/overhead.c b/test/overhead.c
index 2852064..c8d81ac 100644
--- a/test/overhead.c
+++ b/test/overhead.c
@@ -197,7 +197,7 @@ test(fill_t fill_style, const double splits[],
if ((file=H5Fcreate(FILE_NAME_1, H5F_ACC_TRUNC, H5P_DEFAULT, fapl))<0) {
goto error;
}
- if ((dcpl=H5Pcreate(H5P_DATASET_CREATE))<0) goto error;
+ if ((dcpl=H5Pcreate(H5P_DATA_CREATE))<0) goto error;
if (H5Pset_chunk(dcpl, 1, ch_size)<0) goto error;
if ((xfer=H5Pcreate(H5P_DATASET_XFER))<0) goto error;
if (H5Pset_btree_ratios(xfer, splits[0], splits[1], splits[2])<0) {
@@ -335,7 +335,7 @@ main(int argc, char *argv[])
/* Default split ratios */
H5Eset_auto(display_error_cb, NULL);
- if ((xfer=H5Pcreate(H5P_DATASET_XFER))<0) goto error;
+ if ((xfer=H5Pcreate(H5P_DATA_XFER))<0) goto error;
if (H5Pget_btree_ratios(xfer, splits+0, splits+1, splits+2)<0) {
goto error;
}
diff --git a/test/stab.c b/test/stab.c
index 5ea730e..9e84494 100644
--- a/test/stab.c
+++ b/test/stab.c
@@ -134,6 +134,9 @@ test_large(hid_t fapl)
if ((cwg=H5Gcreate(file, "/big", (size_t)nsyms*16+2))<0) goto error;
for (i=0; i<nsyms; i++) {
sprintf(name, "%05d%05d", rand()%100000, i);
+#if 0
+ fprintf(stderr, "%s\n", name);
+#endif
if ((dir=H5Gcreate(cwg, name, 0))<0) goto error;
if (H5Gclose(dir)<0) goto error;
}
diff --git a/test/tselect.c b/test/tselect.c
index 1e72d0f..3ed84ac 100644
--- a/test/tselect.c
+++ b/test/tselect.c
@@ -1856,7 +1856,7 @@ test_select_hyper_union(void)
dataset=H5Dcreate(fid1,"Dataset4",H5T_NATIVE_UCHAR,sid1,H5P_DEFAULT);
CHECK(dataset, FAIL, "H5Dcreate");
- xfer = H5Pcreate (H5P_DATASET_XFER);
+ xfer = H5Pcreate (H5P_DATA_XFER);
CHECK(xfer, FAIL, "H5Pcreate");
ret = H5Pset_hyper_cache(xfer,0,1);
diff --git a/test/tvltypes.c b/test/tvltypes.c
index 019bdfc..5e6441c 100644
--- a/test/tvltypes.c
+++ b/test/tvltypes.c
@@ -152,7 +152,7 @@ test_vltypes_vlen_atomic(void)
CHECK(ret, FAIL, "H5Dwrite");
/* Change to the custom memory allocation routines for reading VL data */
- xfer_pid=H5Pcreate(H5P_DATASET_XFER);
+ xfer_pid=H5Pcreate(H5P_DATA_XFER);
CHECK(xfer_pid, FAIL, "H5Pcreate");
ret=H5Pset_vlen_mem_manager(xfer_pid,test_vltypes_alloc_custom,&mem_used,test_vltypes_free_custom,&mem_used);
@@ -284,7 +284,7 @@ test_vltypes_vlen_compound(void)
CHECK(ret, FAIL, "H5Dwrite");
/* Change to the custom memory allocation routines for reading VL data */
- xfer_pid=H5Pcreate(H5P_DATASET_XFER);
+ xfer_pid=H5Pcreate(H5P_DATA_XFER);
CHECK(xfer_pid, FAIL, "H5Pcreate");
ret=H5Pset_vlen_mem_manager(xfer_pid,test_vltypes_alloc_custom,&mem_used,test_vltypes_free_custom,&mem_used);
@@ -428,7 +428,7 @@ test_vltypes_compound_vlen_atomic(void)
CHECK(ret, FAIL, "H5Dwrite");
/* Change to the custom memory allocation routines for reading VL data */
- xfer_pid=H5Pcreate(H5P_DATASET_XFER);
+ xfer_pid=H5Pcreate(H5P_DATA_XFER);
CHECK(xfer_pid, FAIL, "H5Pcreate");
ret=H5Pset_vlen_mem_manager(xfer_pid,test_vltypes_alloc_custom,&mem_used,test_vltypes_free_custom,&mem_used);
@@ -567,7 +567,7 @@ test_vltypes_vlen_vlen_atomic(void)
CHECK(ret, FAIL, "H5Dwrite");
/* Change to the custom memory allocation routines for reading VL data */
- xfer_pid=H5Pcreate(H5P_DATASET_XFER);
+ xfer_pid=H5Pcreate(H5P_DATA_XFER);
CHECK(xfer_pid, FAIL, "H5Pcreate");
ret=H5Pset_vlen_mem_manager(xfer_pid,test_vltypes_alloc_custom,&mem_used,test_vltypes_free_custom,&mem_used);
diff --git a/test/tfile.c b/test/tfile.c
index f62f5ef..f5ed1b2 100644
--- a/test/tfile.c
+++ b/test/tfile.c
@@ -79,28 +79,41 @@ test_file_create(void)
fid1 = H5Fcreate(FILE1, H5F_ACC_EXCL, H5P_DEFAULT, H5P_DEFAULT);
CHECK(fid1, FAIL, "H5Fcreate");
- /* try to create the same file with H5F_ACC_TRUNC (should fail) */
+ /*
+ * try to create the same file with H5F_ACC_TRUNC. This should fail
+ * because fid1 is the same file and is currently open.
+ */
fid2 = H5Fcreate(FILE1, H5F_ACC_TRUNC, H5P_DEFAULT, H5P_DEFAULT);
VERIFY(fid2, FAIL, "H5Fcreate");
- /* Close the file */
+ /* Close all files */
ret = H5Fclose(fid1);
CHECK(ret, FAIL, "H5Fclose");
+ ret = H5Fclose(fid2);
+ VERIFY(ret, FAIL, "H5Fclose"); /*file should already be closed*/
- /* Try again with H5F_ACC_EXCL (should fail) */
+ /*
+ * Try again with H5F_ACC_EXCL. This should fail because the file already
+ * exists from the previous steps.
+ */
fid1 = H5Fcreate(FILE1, H5F_ACC_EXCL, H5P_DEFAULT, H5P_DEFAULT);
VERIFY(fid1, FAIL, "H5Fcreate");
- /* Test create with H5F_ACC_TRUNC */
- /* Create first file */
+ /* Test create with H5F_ACC_TRUNC. This will truncate the existing file. */
fid1 = H5Fcreate(FILE1, H5F_ACC_TRUNC, H5P_DEFAULT, H5P_DEFAULT);
CHECK(fid1, FAIL, "H5Fcreate");
- /* Try to create first file again (should fail) */
+ /*
+ * Try to truncate first file again. This should fail because fid1 is the
+ * same file and is currently open.
+ */
fid2 = H5Fcreate(FILE1, H5F_ACC_TRUNC, H5P_DEFAULT, H5P_DEFAULT);
VERIFY(fid2, FAIL, "H5Fcreate");
/* Try with H5F_ACC_EXCL (should fail too) */
fid2 = H5Fcreate(FILE1, H5F_ACC_EXCL, H5P_DEFAULT, H5P_DEFAULT);
VERIFY(fid2, FAIL, "H5Fcreate");
@@ -79,28 +79,41 @@ test_file_create(void)
fid2 = H5Fcreate(FILE1, H5F_ACC_TRUNC, H5P_DEFAULT, H5P_DEFAULT);
VERIFY(fid2, FAIL, "H5Fcreate");
- /* Try with H5F_ACC_EXCL (should fail too) */
+ /*
+ * Try with H5F_ACC_EXCL. This should fail too because the file already
+ * exists.
+ */
fid2 = H5Fcreate(FILE1, H5F_ACC_EXCL, H5P_DEFAULT, H5P_DEFAULT);
VERIFY(fid2, FAIL, "H5Fcreate");